(release-3006.22)=
# Salt 3006.22 release notes

<!---
Do not edit this file. This is auto generated.
Edit the templates in doc/topics/releases/templates/
for a given release.
-->


<!--
Add release specific details below
-->

<!--
Do not edit the changelog below.
This is auto generated.
-->
## Changelog

### Fixed

- Fix nftables module check function doesn't understand that braces are optional [#67078](https://github.com/saltstack/salt/issues/67078)
- Fix issue with upstream Netbox API which changed api/ipam/prefixes output to use "scope" FK instead of "site" [#68375](https://github.com/saltstack/salt/issues/68375)
- Fixed SyntaxWarning for invalid escape sequence '\d' in salt/ext/tornado/util.py
  on Python 3.12+ by converting the re_unescape docstring to a raw string. [#68568](https://github.com/saltstack/salt/issues/68568)
- Raise exception if systemd-run is not found when scope is enabled

  Instead of returning None when the systemd-run command is not found
  — which causes the command to fail with an unclear error —
  an exception is now raised, helping to identify the real issue. [#68720](https://github.com/saltstack/salt/issues/68720)
- Remove bundled wheels from virtualenv [#68740](https://github.com/saltstack/salt/issues/68740)


### Added

- Add an option in the chocolatey state and module so that the viruscheck flag can be controlled. [#68558](https://github.com/saltstack/salt/issues/68558)
